@@ -11,6 +11,12 @@ typedef Eo Eio_Model;
 #ifndef _EIO_MODEL_EO_TYPES
 #define _EIO_MODEL_EO_TYPES
 
+/** EflIoFilter function
+ *
+ * @ingroup EflIoFilter
+ */
+typedef int (*EflIoFilter)(void *data, Eio_Model *model, Eina_File_Direct_Info *entry);
+
 
 #endif
 /** Eio model class
@@ -19,7 +25,7 @@ typedef Eo Eio_Model;
  */
 #define EIO_MODEL_CLASS eio_model_class_get()
 
-EWAPI const Eo_Class *eio_model_class_get(void);
+EWAPI const Efl_Class *eio_model_class_get(void);
 
 /**
  * @brief Set children filter callback.
@@ -31,19 +37,22 @@ EWAPI const Eo_Class *eio_model_class_get(void);
  *
  * See also @ref efl_model_children_slice_get.
  *
- * @param[in] filter_cb Filter callback
- * @param[in] userdata User's private data
+ * @param[in] obj The object.
+ * @param[in] filter Filter callback
  *
  * @since 1.11
  *
  * @ingroup Eio_Model
  */
-EOAPI void eio_model_children_filter_set(Eo *obj, Eio_Filter_Direct_Cb filter_cb, void *userdata);
+EOAPI void eio_model_children_filter_set(Eo *obj, void *filter_data, EflIoFilter filter, Eina_Free_Cb filter_free_cb);
 
 /**
- * @brief Custom Eio_Model constructor.
+ * @brief Define the root path of a model.
  *
- * @param[in] path Root path provided by caller
+ * Only possible during construction.
+ *
+ * @param[in] obj The object.
+ * @param[in] path Root path of the model.
  *
  * @since 1.11
  *
@@ -51,5 +60,17 @@ EOAPI void eio_model_children_filter_set(Eo *obj, Eio_Filter_Direct_Cb filter_cb
  */
 EOAPI void eio_model_path_set(Eo *obj, const char *path);
 
+/**
+ * @brief Define the root path of a model.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Root path of the model.
+ *
+ * @since 1.11
+ *
+ * @ingroup Eio_Model
+ */
+EOAPI const char *eio_model_path_get(const Eo *obj);
 
 #endif
