@@ -32,6 +32,7 @@ EOAPI void efl_ui_nstate_activate(Eo *obj);
 /**
  * @brief Maximum number of states
  *
+ * @param[in] obj The object.
  * @param[in] nstate The number of states.
  *
  * @ingroup Efl_Ui_Nstate
@@ -41,6 +42,8 @@ EOAPI void efl_ui_nstate_count_set(Eo *obj, int nstate);
 /**
  * @brief Maximum number of states
  *
+ * @param[in] obj The object.
+ *
  * @return The number of states.
  *
  * @ingroup Efl_Ui_Nstate
@@ -50,6 +53,7 @@ EOAPI int efl_ui_nstate_count_get(const Eo *obj);
 /**
  * @brief Set the particular state given in (0...nstate}.
  *
+ * @param[in] obj The object.
  * @param[in] state The state.
  *
  * @ingroup Efl_Ui_Nstate
@@ -59,18 +63,20 @@ EOAPI void efl_ui_nstate_value_set(Eo *obj, int state);
 /**
  * @brief Get the state value.
  *
+ * @param[in] obj The object.
+ *
  * @return The state.
  *
  * @ingroup Efl_Ui_Nstate
  */
 EOAPI int efl_ui_nstate_value_get(const Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_NSTATE_EVENT_STATE_CHANGED;
+EWAPI extern const Efl_Event_Description _EFL_UI_NSTATE_EVENT_CHANGED;
 
-/** Called when nstate widget changed
+/** Called when the value changed.
  *
  * @ingroup Efl_Ui_Nstate
  */
-#define EFL_UI_NSTATE_EVENT_STATE_CHANGED (&(_EFL_UI_NSTATE_EVENT_STATE_CHANGED))
+#define EFL_UI_NSTATE_EVENT_CHANGED (&(_EFL_UI_NSTATE_EVENT_CHANGED))
 
 #endif
